@@ -21,6 +21,7 @@ from manifestparser import TestManifest
 import mozinfo
 import mozrunner
 from mozrunner.utils import get_metadata_from_egg
+import mozversion
 
 import handlers
 import jsbridge
@@ -124,18 +125,30 @@ class MozMill(object):
         preferences = profile_args.setdefault('preferences', {})
         if isinstance(preferences, dict):
             # Bug 695026 - Re-enable e10s when fully supported
-            preferences['browser.tabs.remote'] = False
-            preferences['browser.tabs.autostart'] = False
+            preferences['browser.tabs.remote.autostart'] = False
             preferences['browser.displayedE10SPrompt'] = 5
 
+            # Bug 1081996: Separate fixes for each e10s testing duration
+            for i in range(1, 10):
+                preferences['browser.tabs.remote.autostart.%s' % i] = False
+                preferences['browser.displayedE10SPrompt.%s' % i] = 5
+
+            preferences['browser.newtabpage.introShown'] = True
+            preferences['browser.uitour.enabled'] = False
             preferences['extensions.jsbridge.port'] = jsbridge_port
             preferences['focusmanager.testmode'] = True
         elif isinstance(preferences, list):
             # Bug 695026 - Re-enable e10s when fully supported
-            preferences.append(('browser.tabs.remote', False))
-            preferences.append(('browser.tabs.autostart', False))
+            preferences.append(('browser.tabs.remote.autostart', False))
             preferences.append(('browser.displayedE10SPrompt', 5))
 
+            # Bug 1081996: Separate fixes for each e10s testing duration
+            for i in range(1, 10):
+                preferences.append(('browser.tabs.remote.autostart.%s' % i, False))
+                preferences.append(('browser.displayedE10SPrompt.%s' % i, 5))
+
+            preferences.append(('browser.newtabpage.introShown', True))
+            preferences.append(('browser.uitour.enabled', False))
             preferences.append(('extensions.jsbridge.port', jsbridge_port))
             preferences.append(('focusmanager.testmode', True))
         else:
@@ -467,7 +480,7 @@ class MozMill(object):
         try:
             mozmill = jsbridge.JSObject(self.bridge, js_module_mozmill)
             app_info = json.loads(mozmill.getApplicationDetails())
-            app_info.update(self.runner.get_repositoryInfo())
+            app_info.update(mozversion.get_version(self.runner.binary))
 
         except JSBridgeDisconnectError:
             # We don't have to call report_disconnect here because
@@ -792,13 +805,20 @@ class CLI(mozrunner.CLI):
         profile_args['preferences'] = {
             # Bug 695026 - Re-enable e10s when fully supported
             'browser.displayedE10SPrompt': 5,
-            'browser.tabs.remote': False,
-            'browser.tabs.autostart': False,
+            'browser.tabs.remote.autostart': False,
 
+            'browser.newtabpage.introShown': True,
+            'browser.uitour.enabled': False,
             'extensions.jsbridge.port': self.jsbridge_port,
             'focusmanager.testmode': True
         }
 
+        # Bug 1081996: Separate fixes for each e10s testing duration
+        preferences = profile_args['preferences']
+        for i in range(1, 10):
+            preferences['browser.tabs.remote.autostart.%s' % i] = False
+            preferences['browser.displayedE10SPrompt.%s' % i] = 5
+
         if self.options.debug:
             prefs = profile_args['preferences']
             prefs['extensions.checkCompatibility'] = False
